@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.106_03';
+our $VERSION = '0.107_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Mon Sep 24 12:48:25 2018 GMT
+# on Mon Oct  1 22:41:03 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1736,7 +1736,7 @@ __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
 __PACKAGE__->status( add => 25170, iridium => '-', 'Iridium 56', 'Tumbling' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
 __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
-__PACKAGE__->status( add => 25173, iridium => '-', 'Iridium 53', 'Tumbling' );
+__PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
 __PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
@@ -1768,7 +1768,7 @@ __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-0
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
 __PACKAGE__->status( add => 25528, iridium => '-', 'Iridium 86', 'Tumbling' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
-__PACKAGE__->status( add => 25530, iridium => 'S', 'Iridium 84', '' );
+__PACKAGE__->status( add => 25530, iridium => '-', 'Iridium 84', 'Tumbling' );
 __PACKAGE__->status( add => 25531, iridium => '+', 'Iridium 83', '' );
 __PACKAGE__->status( add => 25577, iridium => 'S', 'Iridium 20', '' );
 __PACKAGE__->status( add => 25578, iridium => 'S', 'Iridium 11', '' );
@@ -1784,9 +1784,9 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 
 # Summary:
 # Operational [+]: 10
-#       Spare [S]: 13
+#       Spare [S]: 12
 #    Tumbling [-]: 37
-#     Decayed [D]: 37
+#     Decayed [D]: 38
 
 1;
 
